==> lebiniou-data_3.53.0.orig.tar.gz: lebiniou-data-3.53.0/test/lebiniou-test.sh <==
#!/usr/bin/env bash

function check_result() {
    if [ $? -eq 0 ]; then
        echo "[+] Success."
    else
        echo "[!] Failed."
        exit 1
    fi
}

echo "[i] Setting up environment... "
# Input file
export LEBINIOU_SNDFILE=/usr/share/lebiniou/test/EP-Le_cri_des_anges-Intro_4-8bits.flac
# Set random seed
export LEBINIOU_SEED=`date +%s`
# Log sequences
export LEBINIOU_TEST=1
echo "[i] Random seed: "$LEBINIOU_SEED
# FFmpeg
echo "[i] FFmpeg:"
ffmpeg -version 2>&1
# First video
export LEBINIOU_MP4_FILENAME=$AUTOPKGTEST_TMP/video1.mp4
echo -n "[i] Encoding video #1... "
lebiniou -c /usr/share/lebiniou/test/lebiniourc -N -E -W 0 -q > $AUTOPKGTEST_TMP/video1.log
echo "done."
# Second video
export LEBINIOU_MP4_FILENAME=$AUTOPKGTEST_TMP/video2.mp4
echo -n "[i] Encoding video #2... "
lebiniou -c /usr/share/lebiniou/test/lebiniourc -N -E -W 0 -q > $AUTOPKGTEST_TMP/video2.log
echo "done."
echo "[i] Generated videos and logs:"
ls -lh $AUTOPKGTEST_TMP/*.mp4 $AUTOPKGTEST_TMP/*.log
echo "[i] Comparing logs:"
echo -n "    * video1.log: "
sha256sum $AUTOPKGTEST_TMP/video1.log
echo -n "    * video2.log: "
sha256sum $AUTOPKGTEST_TMP/video2.log
diff $AUTOPKGTEST_TMP/video1.log $AUTOPKGTEST_TMP/video2.log
check_result
echo "[i] Extracting per-packet SHA256 hashes:"
echo -n "    * video1.mp4... "
ffmpeg -loglevel quiet -i $AUTOPKGTEST_TMP/video1.mp4 -f framehash $AUTOPKGTEST_TMP/out1.sha256
echo "done."
echo -n "    * video2.mp4... "
ffmpeg -loglevel quiet -i $AUTOPKGTEST_TMP/video2.mp4 -f framehash $AUTOPKGTEST_TMP/out2.sha256
echo "done."
echo "[i] Comparing per-packet hashes:"
diff $AUTOPKGTEST_TMP/out1.sha256 $AUTOPKGTEST_TMP/out2.sha256
check_result
echo "[i] Comparing SHA256 hashes:"
echo -n "    * video1.mp4: "
sha256sum $AUTOPKGTEST_TMP/video1.mp4 | cut -d " " -f 1 > $AUTOPKGTEST_TMP/sha256.1
cat $AUTOPKGTEST_TMP/sha256.1
echo -n "    * video2.mp4: "
sha256sum $AUTOPKGTEST_TMP/video2.mp4 | cut -d " " -f 1 > $AUTOPKGTEST_TMP/sha256.2
cat $AUTOPKGTEST_TMP/sha256.2
diff $AUTOPKGTEST_TMP/sha256.1 $AUTOPKGTEST_TMP/sha256.2
check_result
echo "[i] Comparing ffprobe results:"
echo -n "    * video1.mp4: "
ffprobe -hide_banner $AUTOPKGTEST_TMP/video1.mp4 2>&1 | grep -v Input > $AUTOPKGTEST_TMP/ffprobe.1
sha256sum $AUTOPKGTEST_TMP/ffprobe.1
echo -n "    * video2.mp4: "
ffprobe -hide_banner $AUTOPKGTEST_TMP/video2.mp4 2>&1 | grep -v Input > $AUTOPKGTEST_TMP/ffprobe.2
sha256sum $AUTOPKGTEST_TMP/ffprobe.2
diff $AUTOPKGTEST_TMP/ffprobe.1 $AUTOPKGTEST_TMP/ffprobe.2
check_result

==> lebiniou-data_3.53.1.orig.tar.gz: lebiniou-data-3.53.1/test/lebiniou-test.sh <==
#!/usr/bin/env bash

function check_result() {
    if [ $? -eq 0 ]; then
        echo "[+] Success."
    else
        echo "[!] Failed."
        exit 1
    fi
}

echo "[i] Setting up environment... "
# Input file
export LEBINIOU_SNDFILE=/usr/share/lebiniou/test/EP-Le_cri_des_anges-Intro_4-8bits.flac
# Set random seed
export LEBINIOU_SEED=`date +%s`
# Log sequences
export LEBINIOU_TEST=1
echo "[i] Random seed: "$LEBINIOU_SEED
# FFmpeg
echo "[i] FFmpeg:"
ffmpeg -version 2>&1
# First video
export LEBINIOU_MP4_FILENAME=$AUTOPKGTEST_TMP/video1.mp4
echo -n "[i] Encoding video #1... "
lebiniou -c /usr/share/lebiniou/test/lebiniourc -N -E -W 0 -q > $AUTOPKGTEST_TMP/video1.log
echo "done."
# Second video
export LEBINIOU_MP4_FILENAME=$AUTOPKGTEST_TMP/video2.mp4
echo -n "[i] Encoding video #2... "
lebiniou -c /usr/share/lebiniou/test/lebiniourc -N -E -W 0 -q > $AUTOPKGTEST_TMP/video2.log
echo "done."
echo "[i] Generated videos and logs:"
ls -lh $AUTOPKGTEST_TMP/*.mp4 $AUTOPKGTEST_TMP/*.log
echo "[i] Comparing logs:"
echo -n "    * video1.log: "
sha256sum $AUTOPKGTEST_TMP/video1.log
echo -n "    * video2.log: "
sha256sum $AUTOPKGTEST_TMP/video2.log
diff $AUTOPKGTEST_TMP/video1.log $AUTOPKGTEST_TMP/video2.log
check_result
echo "[i] Extracting per-packet SHA256 hashes:"
echo -n "    * video1.mp4... "
ffmpeg -loglevel quiet -i $AUTOPKGTEST_TMP/video1.mp4 -f framehash - | grep -v " 1," > $AUTOPKGTEST_TMP/out1.sha256
echo "done."
echo -n "    * video2.mp4... "
ffmpeg -loglevel quiet -i $AUTOPKGTEST_TMP/video2.mp4 -f framehash - | grep -v " 1," > $AUTOPKGTEST_TMP/out2.sha256
echo "done."
echo "[i] Generated hashes:"
ls -lh $AUTOPKGTEST_TMP/*.sha256
echo "[i] Comparing per-packet hashes:"
diff $AUTOPKGTEST_TMP/out1.sha256 $AUTOPKGTEST_TMP/out2.sha256
check_result
echo "[i] Comparing ffprobe results:"
echo -n "    * video1.mp4: "
ffprobe -hide_banner $AUTOPKGTEST_TMP/video1.mp4 2>&1 | grep -v Input > $AUTOPKGTEST_TMP/ffprobe.1
sha256sum $AUTOPKGTEST_TMP/ffprobe.1
echo -n "    * video2.mp4: "
ffprobe -hide_banner $AUTOPKGTEST_TMP/video2.mp4 2>&1 | grep -v Input > $AUTOPKGTEST_TMP/ffprobe.2
sha256sum $AUTOPKGTEST_TMP/ffprobe.2
diff $AUTOPKGTEST_TMP/ffprobe.1 $AUTOPKGTEST_TMP/ffprobe.2
check_result
